



; **********************************************************
;  2.LEVEL-Routinen fuer das Interface Transmission Protokoll
; **********************************************************









; Funktion: Write Sektor der Image-Datei
;
; Aufruf: WR_IMG_SEK
; Uebergabeparameter: keine
; Rueckgabeparameter: keine
;  
WR_IMG_SEK:
		CALL	SEND_STD		; Senden von Sektor, Spur und Laufwerk
		;
		LD	HL,(DMAAD)
		LD	B,0
WR_IMG_SEK_A:
		PUSH	BC
		CALL	WR_IMG_SEA		; Write Sektor-Abschnitt der Image-Datei (DISK)
		;
		POP	BC
		INC	B
		LD	A,B
		CP	4
		;
		JR	NZ,WR_IMG_SEK_A
		;
		RET








; Funktion: Write Sektor-Abschnitt der Image-Datei (DISK)
;
; Aufruf: WR_IMG_SEA
; Uebergabeparameter: Register B = 0..3 - lfd. Nr. des 32er Blockes aus dem Sektor
;                     Register HL = Ziel-Adresse fuer den Sektor 
; Rueckgabeparameter: Register HL = Ziel-Adresse fuer weitere Sektoren
; 
WR_IMG_SEA:	; Register retten (Reihenfolge wichtig)
		PUSH	HL
		PUSH	BC
		;
		; Umschalten des Interface Transmission Protokoll (ITP) auf Schreiben (WR)
		CALL	INT_MODE_WR
		;
		; SE_WR_ISEC, lfdNr, D0, D1, ... DE, DF (32)  
		; 
		LD	B,SE_WR_ISEC
		CALL	ITP_SEND_01
		;
		POP	BC
		CALL	ITP_SEND_01		; Uebergabe lfd. Nr. des 32er Blockes aus dem Sektor 
		;
		POP	HL			; Ziel-Adresse fuer den Sektor
		LD	C,32
WR_IMG_SEA_A:
		LD	B,(HL)	
		INC	HL
		;
		PUSH	BC
		PUSH	HL
		;
		CALL	ITP_SEND_01		; Senden der Daten aus Register B
		;
		POP	HL
		POP	BC
		;
		DEC	C
		JR	NZ,WR_IMG_SEA_A
		;
		;
		PUSH	HL
		;
		; Umschalten des Interface Transmission Protokoll (ITP) auf Lesen (RD)
		; erst jetzt werden die Daten wirklich in den RAM geschrieben
		CALL	INT_MODE_RD
		;
		POP	HL
		;
		RET







; Funktion: Read Sektor der Image-Datei
;
; Aufruf: RD_IMG_SEK
; Uebergabeparameter: keine
; Rueckgabeparameter: keine
;  
RD_IMG_SEK:
		CALL	SEND_STD		; Senden von Sektor, Spur und Laufwerk
		;
		LD	HL,(DMAAD)
		LD	B,0
RD_IMG_SEK_A:
		PUSH	BC
		CALL	RD_IMG_SEA		; Read Sektor-Abschnitt der Image-Datei (DISK)
		;
		POP	BC
		INC	B
		LD	A,B
		CP	4
		;
		JR	NZ,RD_IMG_SEK_A
		;

		RET



; Funktion: Read Sektor-Abschnitt der Image-Datei (DISK)
;
; Aufruf: RD_IMG_SEA
; Uebergabeparameter: Register B = 0..3 - lfd. Nr. des 16er Blockes aus dem Sektor
;                     Register HL = Ziel-Adresse fuer den Sektor 
; Rueckgabeparameter: Register HL = Ziel-Adresse fuer weitere Sektoren
; 
RD_IMG_SEA:	; Register retten (Reihenfolge wichtig)
		PUSH	HL
		PUSH	BC
		;
		; Umschalten des Interface Transmission Protokoll (ITP) auf Schreiben (WR)
		CALL	INT_MODE_WR
		;
		; RE_RD_ISEC, lfdNr  
		; 
		LD	B,RE_RD_ISEC
		CALL	ITP_SEND_01
		;
		POP	BC
		CALL	ITP_SEND_01		; Uebergabe lfd. Nr. des 32er Blockes aus dem Sektor 
		;
		; Umschalten des Interface Transmission Protokoll (ITP) auf Lesen (RD)
		CALL	INT_MODE_RD
		;
		LD	B,32
		PUSH	BC
RD_IMG_SEA_A:
		CALL	ITP_RECEIVE_01		; Abholen der Daten, Ergebnis in A
		POP	BC
		POP	HL
		LD	(HL),A	
		INC	HL
		DEC	B
		JR	Z,RD_IMG_SEA_X
		;
		PUSH	HL
		PUSH	BC
		;
		JR	RD_IMG_SEA_A
		
RD_IMG_SEA_X:
		;
		RET




; Funktion: Senden von Sektor, Spur und Laufwerk (STD = Sector, Track and DISK) 
;
; Aufruf: SEND_STD
; Uebergabeparameter: keine
; Rueckgabeparameter: keine
; 
SEND_STD:	; Umschalten des Interface Transmission Protokoll (ITP) auf Schreiben (WR)
		CALL	INT_MODE_WR
		;
		; SE_STD, Sector, TrackHWT, TrackNWT, DISK  
		; 
		LD	B,SE_STD
		CALL	ITP_SEND_01
		;
		LD	A,(SECTOR)
		LD	B,A
		CALL	ITP_SEND_01		; Sector 
		;
		LD	BC,(TRACK)
		PUSH	BC
		CALL	ITP_SEND_01		; TrackHWT
		;
		POP	BC
		LD	B,C
		CALL	ITP_SEND_01		; TrackNWT
		;
		LD	A,(DISKNO)
		LD	B,A
		CALL	ITP_SEND_01		; DISK 
		;
		; Umschalten des Interface Transmission Protokoll (ITP) auf Lesen (RD)
		CALL	INT_MODE_RD
		;
		RET




